@@ -95,6 +95,11 @@ CommandEntry::CommandEntry(Worksheet* worksheet) : WorksheetEntry(worksheet),
     m_promptItemAnimation->setEndValue(1);
     connect(m_promptItemAnimation, &QPropertyAnimation::finished, this, &CommandEntry::animatePromptItem);
 
+    m_promptItem->setDoubleClickBehaviour(WorksheetTextItem::DoubleClickEventBehaviour::Simple);
+    connect(m_promptItem, &WorksheetTextItem::doubleClick, this, &CommandEntry::changeResultCollapsingAction);
+
+    connect(&m_controlElement, &WorksheetControlItem::doubleClick, this, &CommandEntry::changeResultCollapsingAction);
+
     connect(m_commandItem, &WorksheetTextItem::tabPressed, this, &CommandEntry::showCompletion);
     connect(m_commandItem, &WorksheetTextItem::backtabPressed, this, &CommandEntry::selectPreviousCompletion);
     connect(m_commandItem, &WorksheetTextItem::applyCompletion, this, &CommandEntry::applySelectedCompletion);
@@ -748,6 +753,9 @@ void CommandEntry::updateEntry()
         for (ResultItem* item: m_resultItems)
             item->update();
     }
+
+    m_controlElement.isCollapsable = m_resultItems.size() > 0;
+
     animateSizeChange();
 }
 
@@ -1235,25 +1243,27 @@ void CommandEntry::layOutForWidth(qreal w, bool force)
     if (w == size().width() && !force)
         return;
 
-    m_promptItem->setPos(0,0);
+    m_promptItem->setPos(0, 0);
     double x = 0 + m_promptItem->width() + HorizontalSpacing;
     double y = 0;
     double width = 0;
 
-    m_commandItem->setGeometry(x,y, w-x);
-    width = qMax(width, m_commandItem->width());
+    const qreal margin = worksheet()->isPrinting() ? 0 : RightMargin;
+
+    m_commandItem->setGeometry(x, y, w - x - margin);
+    width = qMax(width, m_commandItem->width()+margin);
 
     y += qMax(m_commandItem->height(), m_promptItem->height());
     foreach(WorksheetTextItem* information, m_informationItems) {
         y += VerticalSpacing;
-        y += information->setGeometry(x,y,w-x);
-        width = qMax(width, information->width());
+        y += information->setGeometry(x, y, w - x - margin);
+        width = qMax(width, information->width() + margin);
     }
 
     if (m_errorItem) {
         y += VerticalSpacing;
-        y += m_errorItem->setGeometry(x,y,w-x);
-        width = qMax(width, m_errorItem->width());
+        y += m_errorItem->setGeometry(x,y,w - x - margin);
+        width = qMax(width, m_errorItem->width() + margin);
     }
 
     for (auto* resultItem : m_resultItems)
@@ -1261,8 +1271,8 @@ void CommandEntry::layOutForWidth(qreal w, bool force)
         if (!resultItem || !resultItem->graphicsObject()->isVisible())
             continue;
         y += VerticalSpacing;
-        y += resultItem->setGeometry(x, y, w-x);
-        width = qMax(width, resultItem->width());
+        y += resultItem->setGeometry(x, y, w - x - margin);
+        width = qMax(width, resultItem->width() + margin);
     }
     y += VerticalMargin;
 
@@ -1302,6 +1312,7 @@ void CommandEntry::collapseResults()
     else
         setHidePrompt();
 
+    m_controlElement.isCollapsed = true;
     animateSizeChange();
 }
 
@@ -1322,6 +1333,7 @@ void CommandEntry::expandResults()
     else
         this->updatePrompt();
 
+    m_controlElement.isCollapsed = false;
     animateSizeChange();
 }
 
@@ -1334,3 +1346,14 @@ void CommandEntry::setMidPrompt()
 {
     updatePrompt(MidPrompt);
 }
+
+void CommandEntry::changeResultCollapsingAction()
+{
+    if (m_resultItems.size() == 0)
+        return;
+
+    if (m_resultsCollapsed)
+        expandResults();
+    else
+        collapseResults();
+}
