@@ -21,7 +21,7 @@
 #include "latexrenderer.h"
 using namespace Cantor;
 
-#include <KProcess>
+#include <QProcess>
 #include <QDebug>
 #include <QDir>
 #include <QFileInfo>
@@ -29,6 +29,7 @@ using namespace Cantor;
 #include <QTemporaryFile>
 #include <KColorScheme>
 #include <QUuid>
+#include <QApplication>
 
 #include <config-cantorlib.h>
 #include "settings.h"
@@ -45,10 +46,11 @@ class Cantor::LatexRendererPrivate
     bool success;
     QString latexFilename;
     QString epsFilename;
+    QString uuid;
     QTemporaryFile* texFile;
 };
 
-static const QLatin1String tex("\\documentclass[12pt,fleqn]{article}"\
+static const QLatin1String tex("\\documentclass[fleqn]{article}"\
                          "\\usepackage{latexsym,amsfonts,amssymb,ulem}"\
                          "\\usepackage{amsmath}"\
                          "\\usepackage[dvips]{graphicx}"\
@@ -61,7 +63,8 @@ static const QLatin1String tex("\\documentclass[12pt,fleqn]{article}"\
                          "\\pagestyle{empty}"\
                          "\\begin{document}"\
                          "\\color[rgb]{%5,%6,%7}"\
-                         "%8"\
+                         "\\fontsize{%8}{%8}\\selectfont\n"\
+                         "%9\n"\
                          "\\end{document}");
 
 static const QLatin1String eqnHeader("\\begin{eqnarray*}%1\\end{eqnarray*}");
@@ -159,12 +162,23 @@ QString LatexRenderer::imagePath() const
     return d->epsFilename;
 }
 
-void LatexRenderer::render()
+QString Cantor::LatexRenderer::uuid() const
+{
+    return d->uuid;
+}
+
+bool LatexRenderer::render()
 {
     switch(d->method)
     {
-        case LatexRenderer::LatexMethod:  renderWithLatex(); break;
-        case LatexRenderer::MmlMethod:    renderWithMml(); break;
+        case LatexRenderer::LatexMethod:
+            return renderWithLatex();
+
+        case LatexRenderer::MmlMethod:
+            return renderWithMml();
+
+        default:
+            return false;
     };
 }
 
@@ -174,11 +188,15 @@ void LatexRenderer::renderBlocking()
     connect(this, &LatexRenderer::done, &event, &QEventLoop::quit);
     connect(this, &LatexRenderer::error, &event, &QEventLoop::quit);
 
-    render();
-    event.exec();
+    bool success = render();
+    // We can't emit error before running event loop, so exit by passing false as an error indicator
+    if (success)
+        event.exec();
+    else
+        return;
 }
 
-void LatexRenderer::renderWithLatex()
+bool LatexRenderer::renderWithLatex()
 {
     qDebug()<<"rendering using latex method";
     QString dir=QStandardPaths::writableLocation(QStandardPaths::TempLocation);
@@ -196,12 +214,17 @@ void LatexRenderer::renderWithLatex()
     expressionTex=expressionTex.arg(d->header)
                                .arg(backgroundColor.redF()).arg(backgroundColor.greenF()).arg(backgroundColor.blueF())
                                .arg(foregroundColor.redF()).arg(foregroundColor.greenF()).arg(foregroundColor.blueF());
+
+    int fontPointSize = QApplication::font().pointSize();
+    expressionTex=expressionTex.arg(fontPointSize);
+
     if(isEquationOnly())
     {
         switch(equationType())
         {
             case FullEquation: expressionTex=expressionTex.arg(eqnHeader); break;
             case InlineEquation: expressionTex=expressionTex.arg(inlineEqnHeader); break;
+            case CustomEquation: expressionTex=expressionTex.arg(QLatin1String("%1")); break;
         }
     }
     expressionTex=expressionTex.arg(d->latexCode);
@@ -214,55 +237,74 @@ void LatexRenderer::renderWithLatex()
     QString fileName = d->texFile->fileName();
     qDebug()<<"fileName: "<<fileName;
     d->latexFilename=fileName;
-    KProcess *p=new KProcess( this );
+    QProcess *p=new QProcess( this );
     p->setWorkingDirectory(dir);
 
-    (*p)<<Settings::self()->latexCommand()<<QStringLiteral("-interaction=batchmode")<<QStringLiteral("-halt-on-error")<<fileName;
+    d->uuid = genUuid();
 
-    connect(p, SIGNAL(finished(int,QProcess::ExitStatus)), this, SLOT(convertToPs()) );
-    p->start();
+    qDebug() << Settings::self()->latexCommand();
+    QFileInfo info(Settings::self()->latexCommand());
+    if (info.exists() && info.isExecutable())
+    {
+        p->setProgram(Settings::self()->latexCommand());
+        p->setArguments({QStringLiteral("-jobname=cantor_") + d->uuid, QStringLiteral("-halt-on-error"), fileName});
+
+        connect(p, SIGNAL(finished(int,QProcess::ExitStatus)), this, SLOT(convertToPs()) );
+        p->start();
+        return true;
+    }
+    else
+    {
+        setErrorMessage(QStringLiteral("failed to find latex executable"));
+        return false;
+    }
 }
 
 void LatexRenderer::convertToPs()
 {
-    QString dviFile=d->latexFilename;
-    dviFile.replace(QLatin1String(".tex"), QLatin1String(".dvi"));
-
-    // Create unique filename for eps file, for preventing names collisions
-    QString uuid = QUuid::createUuid().toString();
-    uuid.remove(0, 1);
-    uuid.chop(1);
-    uuid.replace(QLatin1Char('-'), QLatin1Char('_'));
     const QString& dir=QStandardPaths::writableLocation(QStandardPaths::TempLocation);
-    d->epsFilename = dir + QDir::separator() + QLatin1String("cantor_")+uuid+QLatin1String(".eps");
 
-    KProcess *p=new KProcess( this );
+    QString dviFile = dir + QDir::separator() + QStringLiteral("cantor_") + d->uuid + QStringLiteral(".dvi");
+    d->epsFilename = dir + QDir::separator() + QLatin1String("cantor_")+d->uuid+QLatin1String(".eps");
+
+    QProcess *p=new QProcess( this );
     qDebug()<<"converting to eps: "<<Settings::self()->dvipsCommand()<<"-E"<<"-o"<<d->epsFilename<<dviFile;
-    (*p)<<Settings::self()->dvipsCommand()<<QStringLiteral("-E")<<QStringLiteral("-o")<<d->epsFilename<<dviFile;
 
-    connect(p, SIGNAL(finished(int,QProcess::ExitStatus)), this, SLOT(convertingDone()) );
-    p->start();
+    QFileInfo info(Settings::self()->dvipsCommand());
+    if (info.exists() && info.isExecutable())
+    {
+        p->setProgram(Settings::self()->dvipsCommand());
+        p->setArguments({QStringLiteral("-E"), QStringLiteral("-q"), QStringLiteral("-o"), d->epsFilename, dviFile});
+
+        connect(p, SIGNAL(finished(int,QProcess::ExitStatus)), this, SLOT(convertingDone()) );
+        p->start();
+    }
+    else
+    {
+        setErrorMessage(QStringLiteral("failed to find dvips executable"));
+        emit error();
+    }
 }
 
 void LatexRenderer::convertingDone()
 {
-    QFileInfo info(d->latexFilename);
+    QFileInfo info(d->epsFilename);
     qDebug() <<"remove temporary files for " << d->latexFilename;
 
-    delete d->texFile;
-    d->texFile = nullptr;
+    QString pathWithoutExtension = info.path() + QDir::separator() + info.completeBaseName();
+    QFile::remove(pathWithoutExtension + QLatin1String(".log"));
+    QFile::remove(pathWithoutExtension + QLatin1String(".aux"));
+    QFile::remove(pathWithoutExtension + QLatin1String(".dvi"));
 
-    QString pathWithoutExtention = info.path() + QDir::separator() + info.completeBaseName();
-    QFile::remove(pathWithoutExtention + QLatin1String(".log"));
-    QFile::remove(pathWithoutExtention + QLatin1String(".aux"));
-    QFile::remove(pathWithoutExtention + QLatin1String(".tex"));
-    QFile::remove(pathWithoutExtention + QLatin1String(".dvi"));
-
-    if(QFileInfo(d->epsFilename).exists())
+    if(info.exists())
     {
+        delete d->texFile;
+        d->texFile = nullptr;
+
         d->success=true;
         emit done();
-    }else
+    }
+    else
     {
         d->success=false;
         setErrorMessage(QStringLiteral("failed to create the latex preview image"));
@@ -270,8 +312,25 @@ void LatexRenderer::convertingDone()
     }
 }
 
-void LatexRenderer::renderWithMml()
+bool LatexRenderer::renderWithMml()
 {
-    qDebug()<<"WARNING: MML rendering not implemented yet!";
-    emit done();
+    qWarning()<<"WARNING: MML rendering not implemented yet!";
+    emit error();
+    return false;
+}
+
+QString LatexRenderer::genUuid()
+{
+    QString uuid = QUuid::createUuid().toString();
+    uuid.remove(0, 1);
+    uuid.chop(1);
+    uuid.replace(QLatin1Char('-'), QLatin1Char('_'));
+    return uuid;
+}
+
+bool Cantor::LatexRenderer::isLatexAvailable()
+{
+    QFileInfo infoLatex(Settings::self()->latexCommand());
+    QFileInfo infoPs(Settings::self()->dvipsCommand());
+    return infoLatex.exists() && infoLatex.isExecutable() && infoPs.exists() && infoPs.isExecutable();
 }
