@@ -31,6 +31,9 @@
 #include <QUrl>
 #include <QFileInfo>
 #include <QDir>
+#include <QDebug>
+
+#include "settings.h"
 
 static const char description[] =
     I18N_NOOP("KDE Frontend to mathematical applications");
@@ -39,14 +42,11 @@ int main(int argc, char **argv)
 {
     QApplication app(argc, argv);
 
-#ifdef PATH_TO_CANTOR_PLUGINS
     // Add our custom plugins path, where we install our plugins, if it isn't default path
-    const QString& path = QString::fromLocal8Bit(PATH_TO_CANTOR_PLUGINS);
+    const QString& path = Settings::pathToCantorPluginsDir().toLocalFile();
+    qDebug() << "Adding additional application library path" << path;
     if (!QCoreApplication::libraryPaths().contains(path))
         QCoreApplication::addLibraryPath(path);
-#else
-    qDebug() << "PATH_TO_CANTOR_PLUGINS variable is not set (probably a bug), so use the default library paths";
-#endif
 
     KCrash::initialize();
 
@@ -84,9 +84,9 @@ int main(int argc, char **argv)
                      KAboutLicense::GPL,
                      i18n("(C) 2016 Filipe Saraiva<br/>(C) 2009-2015 Alexander Rieder"),
                      QString(),
-                     QLatin1String("https://edu.kde.org/cantor/"));
+                     QLatin1String("https://cantor.kde.org/"));
 
-    about.addAuthor( i18n("Filipe Saraiva"), i18n("Maintainer<br/>Qt5/KF5 port, Scilab and Python backends"), QLatin1String("filipe@kde.org") );
+    about.addAuthor( i18n("Filipe Saraiva"), i18n("Maintainer<br/>Qt5/KF5 port, Scilab and Python backends"), QLatin1String("filipe@kde.org"), QLatin1String("http://filipesaraiva.info/") );
     about.addAuthor( i18n("Nikita Sirgienko"), i18nc("@info:credit", "Developer"), QLatin1String("warquark@gmail.com>"));
     about.addAuthor( i18n("Alexander Semke"), i18nc("@info:credit", "Developer"), QLatin1String("alexander.semke@web.de"));
     about.addAuthor( i18n("Alexander Rieder"), i18n("Original author<br/>Maintainer (2009 - 2015)"), QLatin1String("alexanderrieder@gmail.com") );
@@ -95,12 +95,10 @@ int main(int argc, char **argv)
     about.addAuthor( i18n("Martin Küttler"), i18n("Interface"), QLatin1String("martin.kuettler@gmail.com") );
 
     about.addCredit(QLatin1String("Andreas Kainz"), i18n("Cantor icon"), QLatin1String("kainz.a@gmail.com"));
-    about.addCredit(QLatin1String("Uri Herrera"), i18n("Cantor icon"), QLatin1String("kaisergreymon99@gmail.com"));
+    about.addCredit(QLatin1String("Uri Herrera"), i18n("Cantor icon"), QLatin1String("kaisergreymon99@gmail.com"), QLatin1String("http://nitrux.in/"));
 
     QCommandLineParser parser;
     KAboutData::setApplicationData(about);
-    parser.addVersionOption();
-    parser.addHelpOption();
 
     const QCommandLineOption backendOption(QStringList()<<QLatin1String("b")<<QLatin1String("backend"), i18n("Use  backend <backend>"), QLatin1String("backend"));
     parser.addOption(backendOption);
